<?php

declare(strict_types=1);

namespace Drupal\joinup_group\Plugin\OgGroupResolver;

use Drupal\og\Plugin\OgGroupResolver\RouteGroupResolver;

/**
 * Resolves the group from the route.
 *
 * Use this to make the group (collection or solution) available as a route
 * context on paths that are not defined as entity link templates.
 *
 * This is for example used to display the group_header_block on a route.
 *
 * @OgGroupResolver(
 *   id = "joinup_route_group",
 *   label = "Group entity from current route",
 *   description = @Translation("Checks if the current route is an entity path that belongs to a group entity.")
 * )
 */
class JoinupRouteGroupResolver extends RouteGroupResolver {

  /**
   * {@inheritdoc}
   */
  protected function getContentEntityPaths(): array {
    return [
      '/node/{group}/moderate' => 'node',
      '/node/{node}/reports' => 'node',

      // @todo Can't find usages of these 2 paths.
      '/node/{node}/announcements/list' => 'node',
      '/node/{node}/announcements/send' => 'node',

      '/node/{node}/glossary_export/{arg_1}' => 'node',
      '/node/{node}/reports/actions-log' => 'node',
      '/node/{node}/reports/actions-log/csv' => 'node',
      '/node/{node}/solution/add' => 'node',
    ];
  }

}
